Combinatorial bijections for affiliation network triad indexing
combinatorial_bijections.RdThese functions biject among partitions of at most 3 parts, 3-subsets of natural numbers, and indices for the lexicographic total orders on them.
Usage
index_subset(i)
subset_index(vec)
subset_partition(vec)
partition_subset(lambda)
index_partition(i)
partition_index(lambda)
indexSubset(i)
indexPartition(i)
subsetIndex(vec)
subsetPartition(vec)
partitionIndex(lambda)
partitionSubset(lambda)