Skip to contents

These functions return actor and event node lists.

Usage

V1(graph)

V2(graph)

actor_attr(graph, name, index = V1(graph))

event_attr(graph, name, index = V2(graph))

set_actor_attr(graph, name, index = V1(graph), value)

set_event_attr(graph, name, index = V2(graph), value)

V1(x) <- value

V2(x) <- value

Arguments

graph

An affiliation network.

name

The name of the attribute to set.

index

An optional node sequence to set the attributes of a subset of actor or event nodes.

value

The new value of the attribute for all (or index) actor or event nodes.

x

An affiliation network.

Value

The value of the actor or event attribute, or the input graph with the attribute set.

See also

Original igraph functions: V(), vertex_attr(), set_vertex_attr()

Other modal queries and manipulations: dualize(), mode_addition, mode_counts, schedule()

Examples

data(women_clique)
print(V1(women_clique))
#> + 5/10 vertices, named, from bb1857e:
#> [1] Miss A Miss B Miss C Miss D Miss E
print(V2(women_clique))
#> + 5/10 vertices, named, from bb1857e:
#> [1] Bridge   Dinner   Movies   Dance    Visiting
V1(women_clique)$label <- LETTERS[1:5]
V2(women_clique)$label <- 1:5
plot(prettify_an(women_clique))