Take the dual of an affiliation network
dualize.RdThis function obtains the dual of an affiliation network, in
which the actors and events have swapped roles. To do this, it negates
the logical values of the node type attribute and reorders the
node ids accordingly.
See also
Other modal queries and manipulations:
mode_addition,
mode_counts,
modes,
schedule()
Examples
data(women_clique)
( tab <- table(V(women_clique)$type) )
#>
#> FALSE TRUE
#> 5 5
( proj <- actor_projection(dualize(women_clique)) )
#> IGRAPH 91b91a8 UNW- 5 9 --
#> + attr: name (v/c), weight (e/n)
#> + edges from 91b91a8 (vertex names):
#> [1] Bridge--Movies Bridge--Dance Bridge--Dinner Bridge--Visiting
#> [5] Dinner--Visiting Dinner--Movies Dinner--Dance Movies--Dance
#> [9] Dance --Visiting
vcount(proj) == tab[2]
#> TRUE
#> TRUE