Convenient plotting aesthetics for affiliation networks
prettify.RdGiven an affiliation network, assign the node and link aesthetics to values that produce a neater visualization through plot.igraph than the igraph defaults.
prettify.RdGiven an affiliation network, assign the node and link aesthetics to values that produce a neater visualization through plot.igraph than the igraph defaults.