Skip to contents

Given an affiliation network and a vector of actor node IDs, produce the induced subgraph on the actor nodes together with all event nodes incident to at least two of them. This is called the actors' schedule.

Usage

schedule(graph, actors = V(graph)[V(graph)$type == FALSE])

Arguments

graph

An affiliation network.

actors

A vector of actor nodes in graph.

Value

An igraph object induced from the input graph.

See also

Other modal queries and manipulations: dualize(), mode_addition, mode_counts, modes

Examples

data(women_clique)
schedule(women_clique, actors = V1(women_clique)[seq(3)])
#> IGRAPH 12cc654 UN-B 6 6 -- 
#> + attr: type (v/l), name (v/c)
#> + edges from 12cc654 (vertex names):
#> [1] Miss A--Bridge Miss A--Movies Miss A--Dance  Miss B--Movies Miss B--Dance 
#> [6] Miss C--Bridge