Actors and their shared events
schedule.RdGiven an affiliation network and a vector of actor node IDs, produce the induced subgraph on the actor nodes together with all event nodes incident to at least two of them. This is called the actors' schedule.
See also
Other modal queries and manipulations:
dualize(),
mode_addition,
mode_counts,
modes